/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
var assert = require('assert');
var vscode_1 = require('vscode');
var utils_1 = require('./utils');
var path_1 = require('path');
var fs = require('fs');
suite('workspace-namespace', function () {
    teardown(utils_1.cleanUp);
    test('textDocuments', function () {
        assert.ok(Array.isArray(vscode_1.workspace.textDocuments));
        assert.throws(function () { return vscode_1.workspace.textDocuments = null; });
    });
    test('rootPath', function () {
        assert.ok(utils_1.pathEquals(vscode_1.workspace.rootPath, path_1.join(__dirname, '../testWorkspace')));
        assert.throws(function () { return vscode_1.workspace.rootPath = 'farboo'; });
    });
    test('openTextDocument', function () {
        return vscode_1.workspace.openTextDocument(path_1.join(vscode_1.workspace.rootPath, './far.js')).then(function (doc) {
            assert.ok(doc);
            assert.equal(vscode_1.workspace.textDocuments.length, 1);
        });
    });
    test('openTextDocument, illegal path', function (done) {
        vscode_1.workspace.openTextDocument('funkydonky.txt').then(function (doc) {
            done(new Error('missing error'));
        }, function (err) {
            done();
        });
    });
    test('openTextDocument, untitled is dirty', function (done) {
        if (process.platform === 'win32') {
            return done(); // TODO@Joh this test fails on windows
        }
        vscode_1.workspace.openTextDocument(vscode_1.Uri.parse('untitled://' + path_1.join(vscode_1.workspace.rootPath, './newfile.txt'))).then(function (doc) {
            assert.equal(doc.uri.scheme, 'untitled');
            assert.ok(doc.isDirty);
            done();
        });
    });
    test('openTextDocument, untitled closes on save', function () {
        var path = path_1.join(vscode_1.workspace.rootPath, './newfile.txt');
        return vscode_1.workspace.openTextDocument(vscode_1.Uri.parse('untitled://' + path)).then(function (doc) {
            assert.equal(doc.uri.scheme, 'untitled');
            assert.ok(doc.isDirty);
            var closed;
            var d0 = vscode_1.workspace.onDidCloseTextDocument(function (e) { return closed = e; });
            return doc.save().then(function () {
                assert.ok(closed === doc);
                assert.ok(fs.existsSync(path));
                d0.dispose();
                return utils_1.deleteFile(vscode_1.Uri.file(path_1.join(vscode_1.workspace.rootPath, './newfile.txt')));
            });
        });
    });
    test('events: onDidOpenTextDocument, onDidChangeTextDocument, onDidSaveTextDocument', function () {
        return utils_1.createRandomFile().then(function (file) {
            var disposables = [];
            var onDidOpenTextDocument = false;
            disposables.push(vscode_1.workspace.onDidOpenTextDocument(function (e) {
                assert.ok(utils_1.pathEquals(e.uri.fsPath, file.fsPath));
                onDidOpenTextDocument = true;
            }));
            var onDidChangeTextDocument = false;
            disposables.push(vscode_1.workspace.onDidChangeTextDocument(function (e) {
                assert.ok(utils_1.pathEquals(e.document.uri.fsPath, file.fsPath));
                onDidChangeTextDocument = true;
            }));
            var onDidSaveTextDocument = false;
            disposables.push(vscode_1.workspace.onDidSaveTextDocument(function (e) {
                assert.ok(utils_1.pathEquals(e.uri.fsPath, file.fsPath));
                onDidSaveTextDocument = true;
            }));
            return vscode_1.workspace.openTextDocument(file).then(function (doc) {
                return vscode_1.window.showTextDocument(doc).then(function (editor) {
                    return editor.edit(function (builder) {
                        builder.insert(new vscode_1.Position(0, 0), 'Hello World');
                    }).then(function (applied) {
                        return doc.save().then(function (saved) {
                            assert.ok(onDidOpenTextDocument);
                            assert.ok(onDidChangeTextDocument);
                            assert.ok(onDidSaveTextDocument);
                            while (disposables.length) {
                                disposables.pop().dispose();
                            }
                            return utils_1.deleteFile(file);
                        });
                    });
                });
            });
        });
    });
    test('findFiles', function () {
        return vscode_1.workspace.findFiles('*.js', null).then(function (res) {
            assert.equal(res.length, 1);
            assert.equal(path_1.basename(vscode_1.workspace.asRelativePath(res[0])), 'far.js');
        });
    });
});
//# sourceMappingURL=workspace.test.js.map